@@ -9,6 +9,8 @@ nanotesterr <- function(x, e = "")
   invisible(grepl(e, tryCatch(x, error = identity)[["message"]], fixed = TRUE) || stop("expected error message '", e, "' not generated"))
 
 nanotest(is.list(status()))
+nanotestn(nextstream())
+nanotestn(nextget("pid"))
 nanotestz(status()[["connections"]])
 nanotestz(status()[["daemons"]])
 nanotest(is.character(launch_remote("ws://[::1]:5555")))
@@ -28,17 +30,17 @@ nanotest(is.matrix(dm$data) || is_error_value(dm$data))
 nanotesto(status()[["connections"]])
 nanotest(is.character(status()[["daemons"]]))
 nanotestz(daemons(0L))
-nanotestz(status()[["connections"]])
-nanotestz(status()[["daemons"]])
 nanotesterr(daemons(url = "URL"), "Invalid argument")
 nanotesterr(daemons(-1), "zero or greater")
 nanotesterr(daemons(n = 0, url = "ws://localhost:0"), "1 or greater")
 nanotesterr(daemons(raw(0L)), "must be numeric")
 nanotesterr(daemon("URL"), "Invalid argument")
 nanotesterr(dispatcher(client = "URL"), "at least one")
-nanotestz(daemons(0L))
 nanotest(is_mirai_interrupt(r <- mirai:::mk_interrupt_error()))
 nanotestp(r)
+nanotestz(daemons(0L))
+nanotestz(status()[["connections"]])
+nanotestz(status()[["daemons"]])
 Sys.sleep(1L)
 n <- 3L
 m <- mirai({
@@ -55,37 +57,39 @@ nanotest(identical(call_mirai(m), m))
 nanotest(is_mirai(m))
 nanotest(!unresolved(b))
 nanotest(!unresolved(b2$data))
-nanotest(length(b$data) == 3L)
 nanotest(is.environment(b) && is.character(b$data))
 nanotest(is.environment(b2) && is.character(b2$data))
-Sys.sleep(2.2)
+Sys.sleep(2.5)
 nanotestp(m)
 nanotestp(b)
 `lang obj` <- quote(m + n + 2L)
 args <- list(m = 2L, n = 4L)
 m <- mirai(.expr = `lang obj`, .args = args, .timeout = 2000L)
 nanotest(call_mirai(m)$data == 8L || is_error_value(m$data))
-Sys.sleep(2.2)
+Sys.sleep(2.5)
 nanotest(daemons(url = value <- mirai:::auto_tokenized_url(), dispatcher = FALSE) == value)
 nanotest(grepl("://", launch_remote(status()$daemons), fixed = TRUE))
 nanotestz(daemons(0L))
 Sys.sleep(1L)
-nanotesto(daemons(1L, dispatcher = FALSE, idletime = 500L, timerstart = 1L, cleanup = 0L, .compute = "new"))
-Sys.sleep(2L)
+nanotesto(daemons(1L, dispatcher = FALSE, idletime = 500L, timerstart = 1L, cleanup = 0L, seed = 1546, .compute = "new"))
+nanotest(is.character(nextget("urls", .compute = "new")))
+nanotest(is.integer(nextstream(.compute = "new")))
+Sys.sleep(1.5)
 mn <- mirai("test1", .compute = "new")
 mp <- mirai("test2", .compute = "new")
 Sys.sleep(1L)
 nanotest(mn$data == "test1" || unresolved(mn$data))
 nanotest(mp$data == "test2" || unresolved(mp$data))
 Sys.sleep(1L)
-nanotest(daemons(.compute = "new")[["connections"]] == 0L)
+nanotestz(status(.compute = "new")[["connections"]])
 nanotestz(daemons(0L, .compute = "new"))
 Sys.sleep(1L)
-
 if (.Platform[["OS.type"]] != "windows") {
   nanotest(is_mirai(m <- mirai(TRUE)))
   nanotest(is.character(launch_remote("ws://[::1]:5555", rscript = "/usr/lib/R/bin/Rscript", command = "echo", args = c("Test out:", ., ">/dev/null"))))
-  Sys.sleep(2.2)
+  Sys.sleep(2.5)
+  nanotestn(launch_local(mirai:::auto_tokenized_url(), .compute = "test"))
+  Sys.sleep(1L)
   nanotest(daemons(n = 2L, url = value <- "ws://:0", dispatcher = FALSE) != value)
   nanotestz(daemons(0L))
   Sys.sleep(0.5)
@@ -95,7 +99,9 @@ if (.Platform[["OS.type"]] != "windows") {
   nanotesto(daemons(url = "tcp://:0", token = TRUE))
   nanotestz(daemons(0L))
   Sys.sleep(1L)
-  nanotest(daemons(n = 2, "ws://:0") == 2L)
+  nanotest(daemons(n = 2, "ws://:0", lock = TRUE) == 2L)
+  nanotest(is.integer(nextget("pid")))
+  nanotest(length(nextget("urls")) == 2L)
   Sys.sleep(1L)
   status <- status()[["daemons"]]
   nanotest(is.matrix(status) || is_error_value(status))
@@ -114,6 +120,7 @@ if (.Platform[["OS.type"]] != "windows") {
   }
   nanotest(is.character(saisei(i = 1L)))
   nanotestn(saisei(i = 0L))
+  nanotest(is.character(saisei(i = 1L, force = TRUE)))
   nanotestn(saisei(i = 10L))
   Sys.sleep(0.5)
   nanotestz(daemons(0))
@@ -138,17 +145,17 @@ if (.Platform[["OS.type"]] != "windows") {
   nanotestz(daemons(0))
   Sys.sleep(1L)
 }
-
 if (Sys.getenv("NOT_CRAN") == "true" && .Platform[["OS.type"]] != "windows") {
-  nanotesto(daemons(url = "wss://:0", token = TRUE))
+  nanotesto(daemons(url = "wss://:0", token = TRUE, pass = "test"))
   nanotestn(launch_local(1L))
   nanotest(grepl("CERTIFICATE", launch_remote(1L), fixed = TRUE))
   nanotesterr(launch_local(0:1), "out of bounds")
   nanotesterr(launch_remote(1:2), "out of bounds")
+  nanotest(is.character(nextget("tls")))
   nanotestz(daemons(0L))
   Sys.sleep(1L)
   option <- 15L
-  nanotesto(daemons(1, dispatcher = TRUE, maxtasks = 10L, timerstart = 1L, walltime = 2000L, token = TRUE, lock = TRUE, cleanup = option))
+  nanotesto(daemons(1, dispatcher = TRUE, maxtasks = 10L, timerstart = 1L, walltime = 2000L, seed = 1546, token = TRUE, lock = TRUE, cleanup = option))
   Sys.sleep(1L)
   mq <- mirai("daemon", .timeout = 1000)
   nanotest(call_mirai(mq)$data == "daemon" || is_error_value(mq$data))
@@ -160,5 +167,6 @@ if (Sys.getenv("NOT_CRAN") == "true" && .Platform[["OS.type"]] != "windows") {
   }
   nanotestn(saisei(i = 1L))
   nanotestz(daemons(0))
-  Sys.sleep(2L)
+  Sys.sleep(1L)
 }
+Sys.sleep(1L)
